Package: IRdisplay
Title: 'Jupyter' Display Machinery
Description: 
    An interface to the rich display capabilities of 'Jupyter' front-ends (e.g. 'Jupyter Notebook') <https://jupyter.org>.
    Designed to be used from a running 'IRkernel' session <https://irkernel.github.io>.
Version: 1.1
Authors@R: c(
    person('Thomas', 'Kluyver', role = c('aut', 'cph'), email = 'thomas@kluyver.me.uk'),
    person('Philipp', 'Angerer', role = c('aut', 'cph', 'cre'), email = 'phil.angerer@gmail.com', comment = c(ORCID = "0000-0002-0369-2888")),
    person('Jan', 'Schulz', role = c('aut', 'cph'), email = 'jasc@gmx.net'))
URL: https://github.com/IRkernel/IRdisplay
BugReports: https://github.com/IRkernel/IRdisplay/issues/
Depends: R (>= 3.0.1)
Suggests: testthat, withr
Imports: methods, repr
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-01-04 08:22:43 UTC; phil
Author: Thomas Kluyver [aut, cph],
  Philipp Angerer [aut, cph, cre]
    (<https://orcid.org/0000-0002-0369-2888>),
  Jan Schulz [aut, cph]
Maintainer: Philipp Angerer <phil.angerer@gmail.com>
Repository: CRAN
Date/Publication: 2022-01-04 12:10:16 UTC
Built: R 4.6.0; ; 2026-04-28 04:47:30 UTC; unix
